@@ -45,8 +45,9 @@ import warnings
 
 BCCR_FOLDER = os.path.dirname(os.path.abspath(__file__))
 DATA_FOLDER = os.path.join(BCCR_FOLDER, 'data')
-PICKLE_FILE = os.path.join(DATA_FOLDER, 'indicadores.pkl')
-EXCEL_FILE =  os.path.join(DATA_FOLDER, 'Indicadores.xlsx')
+PICKLE_FILE = os.path.join(DATA_FOLDER, 'indicadores.pkl') # para cuando se actualice localmente el catálogo
+PICKLE_FILE_ONLINE = "https://github.com/randall-romero/bccr/raw/main/bccr/data/indicadores.pkl" # Para mantener catálogo actualizado
+EXCEL_FILE =  'Indicadores.xlsx' # Para actualizar catálogo
 
 
 
@@ -104,6 +105,13 @@ class ServicioWeb:
     token: str
     indicadores: pd.DataFrame
 
+    def __post_init__(self):
+        self.indicadores['medida'].fillna(1, inplace=True)  # el catálogo actual del banco omite esta información en muchos registros
+
+
+
+
+
     def __usuario__(self):
         """Credenciales de usuario
 
@@ -154,7 +162,7 @@ class ServicioWeb:
             número del indicador a descargar.
         FechaInicio : int or str, optional
             fecha de la primera observación a descargar,
-            int -> año, o str -> yyyy/mm/dd (valor predeterminado es '1990/01/01')
+            int -> año, o str -> yyyy/mm/dd (valor predeterminado es '1900/01/01')
         FechaFinal : str, optional
             fecha de la última observación a descargar, formato dd/mm/yyyy (valor predeterminado es fecha del sistema)
 
@@ -209,7 +217,7 @@ class ServicioWeb:
         CAMPOS = ['DESCRIPCION', 'descripcion']
         return pd.DataFrame([self.indicadores[campo].str.contains(frase, case=False) for campo in CAMPOS]).any()
 
-    def buscar(self, todos=None, *, frase=None, algunos=None, frecuencia=None, Unidad=None, Medida=None, periodo=None):
+    def buscar(self, todos=None, *, frase=None, algunos=None, frecuencia=None, Unidad=None, Medida=None, periodo=None, subcuentas=False):
 
         """buscar códigos de indicadores según su descripción
 
@@ -229,6 +237,8 @@ class ServicioWeb:
             mostrar solo indicadores que tengan la medida indicada
         periodo: str, optional
             mostrar solo indicadores que tengan la periodicidad indicada
+        subcuentas: bool, optional (False)
+            incluir subcuentas de cuentas que ya aparecen en los resultados     
 
         Returns
         -------
@@ -242,6 +252,10 @@ class ServicioWeb:
         >>> from bccr import SW
         >>> SW.buscar("IMAE tendencia ciclo")
 
+        Para incluir subcuentas de "IMAE tendencia ciclo" en los resultados
+
+        >>> SW.buscar("IMAE tendencia ciclo", subcuentas=True)
+
         Para buscar un indicador que tenga la frase exacta "Índice de Precios al Consumidor"
 
         >>> SW.buscar(frase="Índice de Precios al Consumidor")
@@ -264,7 +278,8 @@ class ServicioWeb:
         El parámetro 'frecuencia' será discontinuado en algún momento. Se recomienda usar el parámetro 'periodo' para
         cumplir la misma funcionalidad.
         """
-        CAMPOS = ['DESCRIPCION', 'descripcion', 'Unidad','Medida','periodo']
+        #CAMPOS = ['DESCRIPCION', 'descripcion', 'Unidad','Medida','periodo']
+        CAMPOS = ['DESCRIPCION', 'Unidad','Medida','periodo'] # "description" parece ser inconsistente
 
         if frase:
             temp = self.__buscar_frase__(frase)
@@ -297,6 +312,15 @@ class ServicioWeb:
         if periodo:
             results.query('periodo == @periodo', inplace=True)
 
+        # filtrar subcuentas
+        if not subcuentas:
+            todos = list(self.indicadores.loc[results.index,'node'])
+            results = results.loc[[registro.parent not in todos for registro in todos]]
+
+        # Abreviar ruta para ahorrar espacio
+        results.loc[:, 'DESCRIPCION'] = results['DESCRIPCION'].apply(str).str.slice(12, -1)
+
+
         return results[CAMPOS]
 
 
@@ -495,7 +519,7 @@ class ServicioWeb:
             return infer_frequency(serie)
 
 
-    def subcuentas(self, codigo):
+    def subcuentas(self, codigo, *, maxlevel=9, arbol=True):
         """Subcuentas de un indicador
 
         Algunos indicadores pueden desagregarse (por ejemplo, el IMAE total se puede desagregar por actividad económica).
@@ -505,12 +529,16 @@ class ServicioWeb:
         ----------
         codigo : str or int
             código numérico del indicador del que se desea conocer sus subcuentas.
+        maxlevel : int (=9, opcional)
+            profundidad del árbol. 1= solo ramas directas ("hijos"), 2=incluir "nietos", 3=...
+        arbol: bool, (=True, opcional)
+            Imprime árbol de subcuentas si True.
 
         Returns
         -------
         list:
             Los códigos de las subcuentas.
-            Además, el resultado se imprime a pantalla como un árbol de cuentas.
+            Además, el resultado se imprime a pantalla como un árbol de cuentas (si arbol=True).
 
         Examples
         --------
@@ -518,8 +546,10 @@ class ServicioWeb:
         >>> SW.subcuentas(33439)
         """
         cta = self.indicadores.loc[str(codigo), 'node']
-        treestr = RenderTree(cta).by_attr()
-        print(treestr)
+        treestr = RenderTree(cta, maxlevel=1+maxlevel).by_attr()
+        if arbol:
+            print(treestr)
+        
         return re.findall('\[([0-9]+)\]', treestr)
 
     def datos(self, *codigos, FechaInicio=None, FechaFinal=None, func=None, freq=None, fillna=None, **indicadores):
@@ -758,4 +788,4 @@ class ServicioWeb:
 SW = ServicioWeb(nombre = 'Paquete BCCR Python',
                  correo = 'paquete.bccr.python@outlook.com',
                  token = '5CMRCBTHMT',
-                 indicadores = pd.read_pickle(PICKLE_FILE))
\ No newline at end of file
+                 indicadores = pd.read_pickle(PICKLE_FILE_ONLINE))
\ No newline at end of file
