@@ -4,6 +4,7 @@ from dash.dependencies import Input, Output, State
 from dash import dash_table
 from dash import dcc
 from dash import html
+# import bootstrap_components as dbc  #todo: sería una extensión interesante
 from dash_extensions import Download
 from dash_extensions.snippets import send_data_frame
 from dash.dash_table.Format import Format, Scheme
@@ -18,6 +19,11 @@ import webbrowser
 
 DATOS_PARA_DESCARGAR = [pd.DataFrame()]
 
+UNIDADES = SW.indicadores['Unidad'].value_counts().index.to_list()
+PERIODICIDAD = SW.indicadores['periodo'].value_counts().index.to_list()
+
+
+
 
 # Esta parte controla asuntos de estética de la página
 external_stylesheets = ['https://codepen.io/chriddyp/pen/bWLwgP.css']
@@ -235,9 +241,21 @@ app.layout = html.Div([
                                      id='buscar-códigos',
                                      placeholder='Escriba acá los términos que desea buscar...',
                                      value='',
-                                     style={'padding': 10, 'width': '50%'}
+                                     style={'padding': 10, 'width': '25%'}
                                  ),
-                                 html.Button('Buscar', id='buscar-códigos-button', n_clicks=0),
+                                 dcc.Dropdown(
+                                    id='filtrar-unidades',
+                                    options=[dict(label= valor, value=valor) for valor in [''] + UNIDADES],
+                                    value='',
+                                    style={'padding': 10, 'width': '25%', "display": "inline-block"}
+                                 ), # fin de función para filtrar unidades
+                                 dcc.Dropdown(
+                                        id='filtrar-periodos',
+                                        options=[dict(label= valor, value=valor) for valor in [''] + PERIODICIDAD],
+                                        value='',
+                                        style={'padding': 10, 'width': '25%', "display": "inline-block"}
+                                    ), # fin de función para filtrar periodos
+                                 dcc.Markdown('Tipo de búsqueda'),
                                  dcc.RadioItems(
                                      id='tipo-búsqueda',
                                      options=[
@@ -248,6 +266,17 @@ app.layout = html.Div([
                                      value='todos',
                                      labelStyle={'display': 'inline-block'}
                                  ),
+                                 dcc.Markdown('Incluir subcuentas'),
+                                 dcc.RadioItems(
+                                     id='incluir-subcuentas',
+                                     options=[
+                                         {'label': 'No', 'value': 'No'},
+                                         {'label': 'Sí', 'value': 'Sí'}
+                                     ],
+                                     value='No',
+                                     labelStyle={'display': 'inline-block'}
+                                 ),
+                                 html.Button('Buscar', id='buscar-códigos-button', n_clicks=0),
                                  dcc.Textarea(id='buscar-mensaje',
                                               value='Ingrese los términos deseados en el cuadro de arriba',
                                               readOnly=True,
@@ -262,7 +291,7 @@ app.layout = html.Div([
                                      filter_action='native',
                                      columns=[
                                          {'name': 'Código', 'id': 'codigo'},
-                                         {'name': 'Descripción', 'id': 'descripcion'},
+                                         #{'name': 'Descripción', 'id': 'descripcion'}, ya no se reporta
                                          {'name': 'Ruta', 'id': 'DESCRIPCION'},
                                          {'name': 'Unidad', 'id': 'Unidad'},
                                          {'name': 'Medida', 'id': 'Medida'},
@@ -274,12 +303,20 @@ app.layout = html.Div([
                      # PANEL 4: QUIÉN ES ESTE INDICADOR================================================
                      dcc.Tab(label='¿Quién?',
                              children=[
+                                 dcc.Markdown("Código de cuenta ⇒"),
                                  dcc.Input(
                                      id='quién-es-código',
                                      placeholder='Código...',
                                      value='',
                                      style={'padding': 10, 'width': '10%'}
                                  ),
+                                 dcc.Markdown("Número de subniveles en subcuentas ⇒"),
+                                 dcc.Input(
+                                     id='profundidad-arbol',
+                                     placeholder='(opcional: 1,2,...8)',
+                                     value='',
+                                     style={'padding': 10, 'width': '10%'}
+                                 ),
                                  html.Button('Buscar', id='quién-button', n_clicks=0),
                                  html.Div(
                                      children=[
@@ -336,17 +373,19 @@ def add_row(n_clicks, rows, columns):
     Output('subcuentas', 'value'),
     Input('quién-button', 'n_clicks'),
     State('quién-es-código', 'value'),
+    State('profundidad-arbol', 'value'),
 )
-def quién_subcuentas(n_clicks, código):
+def quién_subcuentas(n_clicks, código, maxlevel):
 
     if código in SW.indicadores.index:
+        maxlevel = int(maxlevel if maxlevel else 9)
 
         with io.StringIO() as buf, redirect_stdout(buf):
             SW.quien(código)
             quien = buf.getvalue()
 
         with io.StringIO() as buf, redirect_stdout(buf):
-            SW.subcuentas(código)
+            SW.subcuentas(código, maxlevel=maxlevel)
             subcuentas = buf.getvalue()
     elif código == '':
         quien = subcuentas = f'Escriba el código deseado en el espacio de arriba.'
@@ -368,12 +407,16 @@ def quién_subcuentas(n_clicks, código):
     Input('buscar-códigos-button', 'n_clicks'),
     State('buscar-códigos', 'value'),
     State('tipo-búsqueda', 'value'),
+    State('filtrar-unidades', 'value'),
+    State('filtrar-periodos', 'value'),
+    State('incluir-subcuentas', 'value'),
 )
-def mostrar_códigos(n_clicks, frase, tipo):
+def mostrar_códigos(n_clicks, frase, tipo,unidades,periodos,subcuentas):
+    subcuentas = (subcuentas=='Sí')
 
     if frase:
         # Acomodar la lista de indicadores
-        resultados = SW.buscar(**{tipo: frase})
+        resultados = SW.buscar(**{tipo: frase}, Unidad=unidades, periodo=periodos, subcuentas=subcuentas)
 
         # Acomodar los datos descargados como un diccionario, para que lo lea dash
         tabla = resultados.reset_index().to_dict(orient='records')
@@ -408,7 +451,7 @@ def display_output(n_clicks, rows, FechaInicio, FechaFinal, freq, func, fillna):
 
     # Acomodar la lista de indicadores
     indicadores = dict()
-    for item in rows:
+    for item in rows:       
         indicadores[item['nombre']] = item['código']
 
     # Interpretar parámetros freq y fillna
